﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Windows.Forms;
using HeuristicLab.Common.Resources;

namespace HeuristicLab.Analysis.Views {
  public partial class DataTableVisualPropertiesDialog : Form {
    protected DataTable Content { get; private set; }
    private DataTableVisualProperties originalDataTableVPs;
    private Dictionary<string, DataRowVisualProperties> originalDataRowVPs;

    public DataTableVisualPropertiesDialog(DataTable dataTable) {
      InitializeComponent();
      Content = dataTable;
      originalDataTableVPs = (DataTableVisualProperties)Content.VisualProperties.Clone();
      originalDataRowVPs = new Dictionary<string, DataRowVisualProperties>();
      foreach (DataRow row in Content.Rows)
        originalDataRowVPs.Add(row.Name, (DataRowVisualProperties)row.VisualProperties.Clone());
      seriesListView.Items.Clear();
      seriesListView.SmallImageList = new ImageList();
      seriesListView.SmallImageList.Images.Add(VSImageLibrary.Graph);
      FillSeriesListView();
    }

    private void FillSeriesListView() {
      seriesListView.SelectedIndices.Clear();
      foreach (DataRow row in Content.Rows) {
        seriesListView.Items.Add(new ListViewItem(row.Name, 0));
      }
      seriesListView.SelectedIndices.Add(0);
    }

    private void seriesListView_SelectedIndexChanged(object sender, System.EventArgs e) {
      if (seriesListView.SelectedItems.Count == 0) return;
      string rowName = seriesListView.SelectedItems[0].Text;
      dataRowVisualPropertiesControl.Content = Content.Rows[rowName].VisualProperties;
    }

    private void okButton_Click(object sender, System.EventArgs e) {
      DialogResult = DialogResult.OK;
      Close();
    }

    private void cancelButton_Click(object sender, System.EventArgs e) {
      DialogResult = DialogResult.Cancel;
      Content.VisualProperties = originalDataTableVPs;
      foreach (DataRow row in Content.Rows) {
        row.VisualProperties = originalDataRowVPs[row.Name];
      }
      Close();
    }
  }
}
